@@ -1037,7 +1037,8 @@ a string that contains the response entity body.
                         feedparser.feed(info)
                         info = feedparser.close()
                         feedparser._parse = None
-                    except IndexError:
+                    #// FIXED from except IndexError //#
+                    except:
                         self.cache.delete(cachekey)
                         cachekey = None
                         cached_value = None
@@ -1060,7 +1061,8 @@ a string that contains the response entity body.
                 for header in vary_headers:
                     key = '-varied-%s' % header
                     value = info[key]
-                    if headers.get(header, '') != value:
+                    #// FIXED from "if headers.get(header, '') != value" //#
+                    if headers.get(header, '') != value and headers.get(header) != value:
                             cached_value = None
                             break
 
@@ -1121,7 +1123,7 @@ a string that contains the response entity body.
                 else:
                     self.cache.delete(cachekey)
                     content = new_content 
-            else: 
+            else:
                 cc = _parse_cache_control(headers)
                 if cc.has_key('only-if-cached'):
                     info['status'] = '504'
